# 🛠️ openai-commands (`@openai`)

`@openai` is a bash interface to the [OpenAI API](https://beta.openai.com/docs/introduction).

```bash
pip install openai-commands
```

|   |   |   |
| --- | --- | --- |
| 🛠️[`prompt completion`](https://github.com/kamangir/openai-commands/tree/main/openai_commands/completion#%EF%B8%8F-prompt-completion) [![image](https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true)](https://github.com/kamangir/openai-commands/tree/main/openai_commands/completion#%EF%B8%8F-prompt-completion) basic prompt completion. | 🛠️[`code generation`](https://github.com/kamangir/openai-commands/tree/main/openai_commands/completion#%EF%B8%8F-code-generation) [![image](https://github.com/kamangir/openai-commands/blob/main/assets/completion_i2i_function.png?raw=true)](https://github.com/kamangir/openai-commands/tree/main/openai_commands/completion#%EF%B8%8F-code-generation) example notebooks to [generate a python functions](./notebooks/completion_ai_function_py.ipynb), special case for [image to image python functions](./notebooks/completion_i2i_function.ipynb), and to [write a bash script](./notebooks/completion_ai_function_bash.ipynb) to use a script, for example, [vancouver-watching](https://github.com/kamangir/vancouver-watching). | 🛠️[`VisuaLyze`](https://github.com/kamangir/openai-commands/tree/main/openai_commands/VisuaLyze) [![image](https://github.com/kamangir/openai-commands/assets/1007567/7c0ed5f7-6941-451c-a17e-504c6adab23f)](https://github.com/kamangir/openai-commands/tree/main/openai_commands/VisuaLyze) How about calling it "VisuaLyze"? This name combines "visualize" and "analyze," reflecting the tool's capability to generate custom data visualizations and analyze user input through AI - OpenAI |
| 🛠️[`gpt`](https://github.com/kamangir/openai-commands/tree/main/openai_commands/gpt) [![image](https://github.com/kamangir/assets/raw/main/blue-plugin/marquee.png?raw=true)](https://github.com/kamangir/openai-commands/tree/main/openai_commands/gpt) co-authored with ChapGPT. | 🛠️[`OpenAI Vision API`](https://github.com/kamangir/openai-commands/tree/main/openai_commands/vision) [![image](https://raw.githubusercontent.com/kamangir/assets/main/vanwatch/2023-11-25-openai-vision/ButeNorthDavie.jpg)](https://github.com/kamangir/openai-commands/tree/main/openai_commands/vision) implements the [OpenAI vision API](https://platform.openai.com/docs/guides/vision). | 🛠️[`image generation`](https://github.com/kamangir/openai-commands/tree/main/openai_commands/images) [![image](https://github.com/kamangir/openai-commands/blob/main/assets/DALL-E.png?raw=true)](https://github.com/kamangir/openai-commands/tree/main/openai_commands/images) sentence -> image, text -> mural, images |
| 🛠️[`literature review`](https://github.com/kamangir/openai-commands/tree/main/openai_commands/literature_review) [![image](https://github.com/kamangir/assets/blob/main/openai_commands/literature-review/marquee.png?raw=true)](https://github.com/kamangir/openai-commands/tree/main/openai_commands/literature_review) literature review using OpenAI API. |  |  |

---


[![PyPI version](https://img.shields.io/pypi/v/openai-commands.svg)](https://pypi.org/project/openai-commands/)

---

To use on [AWS SageMaker](https://aws.amazon.com/sagemaker/) replace `<plugin-name>` with the name of the plugin and follow [these instructions](https://github.com/kamangir/notebooks-and-scripts/blob/main/SageMaker.md).

---
built by [`abcli-9.188.1-current`](https://github.com/kamangir/awesome-bash-cli), based on [`openai_commands-3.60.1`](https://github.com/kamangir/openai-commands).
